@@ -20,12 +20,10 @@
 from __future__ import annotations
 
 import argparse
+import logging
 
 from argparse import _SubParsersAction
-from logging import debug
-from logging import warning
-from typing import Callable
-from typing import List
+from collections.abc import Callable
 
 import coloredlogs
 
@@ -38,6 +36,7 @@ from matrixctl.deluser import subparser_deluser
 from matrixctl.deluser_jitsi import subparser_deluser_jitsi
 from matrixctl.deploy import subparser_deploy
 from matrixctl.maintenance import subparser_maintenance
+from matrixctl.purge_history import subparser_purge_history
 from matrixctl.rooms import subparser_rooms
 from matrixctl.server_notice import subparser_server_notice
 from matrixctl.start import subparser_restart
@@ -60,6 +59,9 @@ __email__: str = "Michael@MichaelSasser.org"
 #              user_admin_api.rst
 
 
+logger = logging.getLogger(__name__)
+
+
 def setup_parser() -> argparse.ArgumentParser:
     """Use this class to initialize the parser and the subparsers.
 
@@ -82,13 +84,14 @@ def setup_parser() -> argparse.ArgumentParser:
     subparsers: _SubParsersAction = parser.add_subparsers()
 
     # Subparsers
-    subparsers_tuple: List[Callable[[_SubParsersAction], None]] = [
+    subparsers_tuple: list[Callable[[_SubParsersAction], None]] = [
         subparser_adduser,
         subparser_deluser,
         subparser_adduser_jitsi,
         subparser_deluser_jitsi,
         subparser_user,
         subparser_users,
+        subparser_purge_history,
         subparser_rooms,
         subparser_delroom,
         subparser_update,
@@ -123,12 +126,16 @@ def setup_logging(debug_mode: bool) -> None:
     None
 
     """
-    coloredlogs.DEFAULT_LOG_FORMAT = (
-        "%(asctime)s [%(module)s:%(lineno)d (%(funcName)s)] - %(levelname)s "
-        "- %(message)s"
+    # Default coloredlogs.DEFAULT_LOG_FORMAT:
+    # %(asctime)s %(hostname)s %(name)s[%(process)d] %(levelname)s %(message)s
+
+    coloredlogs.install(
+        level="DEBUG" if debug_mode else "INFO",
+        fmt=(
+            "%(asctime)s %(name)s:%(lineno)d [%(funcName)s] %(levelname)s "
+            "%(message)s"
+        ),
     )
-    coloredlogs.DEFAULT_LOG_LEVEL = 0 if debug_mode else 21
-    coloredlogs.install()
 
 
 def main() -> int:
@@ -150,11 +157,11 @@ def main() -> int:
 
     setup_logging(args.debug)
 
-    debug(f"{args=}")
+    logger.debug(f"{args=}")
 
     if args.debug:
-        debug("Disabing help on AttributeError")
-        warning(
+        logger.debug("Disabing help on AttributeError")
+        logger.warning(
             "In debugging mode help is disabled! If you don't use any "
             "attibutes, the program will throw a AttributeError like: "
             "\"AttributeError: 'Namespace' object has no attribute 'func\".'"
