@@ -19,11 +19,11 @@
 
 from __future__ import annotations
 
+import logging
+
 from argparse import ArgumentParser
 from argparse import Namespace
 from argparse import _SubParsersAction as SubParsersAction
-from logging import fatal
-from typing import List
 
 from tabulate import tabulate
 
@@ -37,6 +37,9 @@ __author__: str = "Michael Sasser"
 __email__: str = "Michael@MichaelSasser.org"
 
 
+logger = logging.getLogger(__name__)
+
+
 def subparser_rooms(subparsers: SubParsersAction) -> None:
     """Create a subparser for the ``matrixctl rooms`` command.
 
@@ -93,7 +96,7 @@ def rooms(arg: Namespace) -> int:
     """
     toml: TOML = TOML()
     from_room: int = 0
-    rooms_list: List[JsonDict] = []
+    rooms_list: list[JsonDict] = []
 
     api: API = API(toml.get("API", "Domain"), toml.get("API", "Token"))
     api.url.path = "rooms"
@@ -117,7 +120,7 @@ def rooms(arg: Namespace) -> int:
         try:
             lst: JsonDict = api.request().json()
         except InternalResponseError:
-            fatal("Could not get the room table.")
+            logger.critical("Could not get the room table.")
 
             return 1
 
