@@ -19,12 +19,11 @@
 
 from __future__ import annotations
 
+import logging
+
 from argparse import ArgumentParser
 from argparse import Namespace
 from argparse import _SubParsersAction as SubParsersAction
-from logging import fatal
-from typing import List
-from typing import Tuple
 
 from tabulate import tabulate
 
@@ -39,6 +38,9 @@ __author__: str = "Michael Sasser"
 __email__: str = "Michael@MichaelSasser.org"
 
 
+logger = logging.getLogger(__name__)
+
+
 def subparser_users(subparsers: SubParsersAction) -> None:
     """Create a subparser for the ``matrixctl users`` command.
 
@@ -120,7 +122,7 @@ def users(arg: Namespace) -> int:
     toml: TOML = TOML()
     len_domain = len(toml.get("API", "Domain")) + 1  # 1 for :
     from_user: int = 0
-    users_list: List[JsonDict] = []
+    users_list: list[JsonDict] = []
 
     # ToDo: API bool
     api: API = API(toml.get("API", "Domain"), toml.get("API", "Token"))
@@ -137,7 +139,7 @@ def users(arg: Namespace) -> int:
         try:
             lst: JsonDict = api.request().json()
         except InternalResponseError:
-            fatal("Could not get the user table.")
+            logger.critical("Could not get the user table.")
 
             return 1
 
@@ -148,7 +150,7 @@ def users(arg: Namespace) -> int:
         except KeyError:
             break
 
-    user_list: List[Tuple[str, str, str, str, str, str]] = []
+    user_list: list[tuple[str, str, str, str, str, str]] = []
 
     for user in users_list:
         name = user["name"][1:-len_domain]
